OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Nem írható a \"config\" könyvtár!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Ez rendszerint úgy oldható meg, hogy írási jogot adunk a webszervernek a config könyvtárra.",
    "See %s" : "Lásd %s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Avagy, ha jobbnak tűnik tarthatod a config.php fájlt olvashatónak, csak engedélyezd a \"config_is_read_only\" kapcsolót.",
    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Ez rendszerint úgy oldható meg, hogy írási jogot adunk a webszervernek a config könyvtárra. Lásd: %s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Avagy, ha jobbnak tűnik tarthatod a config.php fájlt olvashatónak, csak engedélyezd a \"config_is_read_only\" kapcsolót. Továbbiak itt:%s",
    "Sample configuration detected" : "A példabeállítások vannak beállítva",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Úgy tűnik a példakonfigurációt próbálja ténylegesen használni. Ez nem támogatott, és működésképtelenné teheti a telepítést. Kérlek olvasd el a dokumentációt és azt követően változtas a config.php-n!",
    "%1$s and %2$s" : "%1$s és %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s és %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s és %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s és %5$s",
    "Education Edition" : "Oktatási verzió",
    "Enterprise bundle" : "Vállalati csomag",
    "Groupware bundle" : "Csoportmunka csomag",
    "Social sharing bundle" : "Közösségi megosztás csomag",
    "PHP %s or higher is required." : "PHP %s vagy ennél újabb szükséges.",
    "PHP with a version lower than %s is required." : "Ennél régebbi PHP szükséges: %s.",
    "%sbit or higher PHP required." : "%sbites vagy újabb PHP szükséges.",
    "Following databases are supported: %s" : "A következő adatbázisok támogatottak: %s",
    "The command line tool %s could not be found" : "A parancssori eszköz nem található: %s",
    "The library %s is not available." : "A könyvtár %s nem áll rendelkezésre.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "%1$s könyvtár %2$s vagy újabb verziója szükséges - elérhető verzió: %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "%1$s könyvtár %2$s vagy régebbi verziója szükséges - elérhető verzió: %3$s.",
    "Following platforms are supported: %s" : "Ezek a platformok támogatottak: %s",
    "Server version %s or higher is required." : "%s vagy újabb szerver verzió szükséges.",
    "Server version %s or lower is required." : "%s vagy régebbi szerver verzió szükséges.",
    "Logged in user must be an admin" : "A bejelentkezett felhasználónak rendszergazdának kell lennie",
    "Authentication" : "Hitelesítés",
    "Unknown filetype" : "Ismeretlen fájl típus",
    "Invalid image" : "Hibás kép",
    "Avatar image is not square" : "Az avatár kép nem négyzetes.",
    "today" : "ma",
    "tomorrow" : "holnap",
    "yesterday" : "tegnap",
    "_in %n day_::_in %n days_" : ["%n napon belül","%n napon belül"],
    "_%n day ago_::_%n days ago_" : ["%n napja","%n napja"],
    "next month" : "következő hónap",
    "last month" : "múlt hónapban",
    "_in %n month_::_in %n months_" : ["%n hónapon belül","%n hónapon belül"],
    "_%n month ago_::_%n months ago_" : ["%n hónapja","%n hónapja"],
    "next year" : "következő évben",
    "last year" : "tavaly",
    "_in %n year_::_in %n years_" : ["%n éven belül","%n éven belül"],
    "_%n year ago_::_%n years ago_" : ["%n éve","%n éve"],
    "_in %n hour_::_in %n hours_" : ["%n órán belül","%n órán belül"],
    "_%n hour ago_::_%n hours ago_" : ["%n órája","%n órája"],
    "_in %n minute_::_in %n minutes_" : ["%n percen belül","%n percen belül"],
    "_%n minute ago_::_%n minutes ago_" : ["%n perce","%n perce"],
    "in a few seconds" : "pár másodpercen belül",
    "seconds ago" : "pár másodperce",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "A(z) %s azonosítójú modul nem létezik. Kérlek engedélyezd az app beállításaidban, vagy lépj kapcsolatba a rendszergazdával.",
    "File name is a reserved word" : "A fajl neve egy rezervált szó",
    "File name contains at least one invalid character" : "A fájlnév legalább egy érvénytelen karaktert tartalmaz!",
    "File name is too long" : "A fájlnév túl hosszú!",
    "Dot files are not allowed" : "Pontozott fájlok nem engedétlyezettek",
    "Empty filename is not allowed" : "Üres fájlnév nem engedétlyezett",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "\"%s\" alkalmazás nem lehet telepíteni, mert az appinfo fájl nem olvasható.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "\"%s\" alkalmazás nem lehet telepíteni, mert nem kompatibilis a szerver jelen verziójával.",
    "__language_name__" : "Magyar",
    "This is an automatically sent email, please do not reply." : "Ez egy automatikusan küldött levél, kérlek ne válaszolj rá.",
    "Help" : "Súgó",
    "Apps" : "Alkalmazások",
    "Settings" : "Beállítások",
    "Log out" : "Kijelentkezés",
    "Users" : "Felhasználók",
    "Unknown user" : "Ismeretlen felhasználó",
    "Overview" : "Áttekintés",
    "Basic settings" : "Alapvető beállítások",
    "Sharing" : "Megosztás",
    "Security" : "Biztonság",
    "Groupware" : "Csoportmunka",
    "Additional settings" : "További beállítások",
    "Personal info" : "Személyes információk",
    "Mobile & desktop" : "Mobil és deszktop",
    "%s enter the database username and name." : "%s add meg az adatbázis nevét és felhasználónevét",
    "%s enter the database username." : "%s adja meg az adatbázist elérő felhasználó login nevét.",
    "%s enter the database name." : "%s adja meg az adatbázis nevét.",
    "%s you may not use dots in the database name" : "%s az adatbázis neve nem tartalmazhat pontot",
    "Oracle connection could not be established" : "Az Oracle kapcsolat nem hozható létre",
    "Oracle username and/or password not valid" : "Az Oracle felhasználói név és/vagy jelszó érvénytelen",
    "PostgreSQL username and/or password not valid" : "A PostgreSQL felhasználói név és/vagy jelszó érvénytelen",
    "You need to enter details of an existing account." : "Egy már létező fiók adatait kell megadnod.",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "A Mac OS X nem támogatott és %s nem lesz teljesen működőképes. Csak saját felelősségre használja!",
    "For the best results, please consider using a GNU/Linux server instead." : "A legjobb eredmény érdekében érdemes GNU/Linux-alapú szervert használni.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Úgy tűnik, hogy ez a %s példány 32-bites PHP környezetben fut és az open_basedir konfigurálva van a php.ini fájlban. Ez 4 GB-nál nagyobb fájlok esetén problémákat okozhat így erősen ellenjavallt.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Kérlek távolítsd el az open_basedir beállítást a php.ini-ből, vagy válts 64bit-es PHP-ra.",
    "Set an admin username." : "Állítson be egy rendszergazdai felhasználónevet!",
    "Set an admin password." : "Állítson be egy rendszergazdai jelszót!",
    "Can't create or write into the data directory %s" : "Nem sikerült  létrehozni vagy irni  a \"data\" könyvtárba %s",
    "Invalid Federated Cloud ID" : "Érvénytelen Egyesített Felhő Azonosító",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Az %s megosztási alrendszernek támogatnia kell az OCP\\Share_Backend interface-t",
    "Sharing backend %s not found" : "A %s megosztási alrendszer nem található",
    "Sharing backend for %s not found" : "%s megosztási alrendszere nem található",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s megosztotta veled »%2$s« és hozzá akarja adni:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s megosztotta veled »%2$s« és hozzá akarja adni",
    "»%s« added a note to a file shared with you" : "»%s« megjegyést fűzött a veled megosztott fájlhoz",
    "Open »%s«" : "»%s« megnyitása",
    "%1$s via %2$s" : "%1$s - %2$s",
    "You are not allowed to share %s" : "Nincs jogosultságod %s megosztására",
    "Can’t increase permissions of %s" : "A(z) %s engedélyei nem kibővíthetők",
    "Files can’t be shared with delete permissions" : "A fájlok nem megoszthatók törlési joggal",
    "Files can’t be shared with create permissions" : "Fájlok nem oszthatók meg létrehozási joggal",
    "Expiration date is in the past" : "A lejárati dátum már elmúlt",
    "Can’t set expiration date more than %s days in the future" : "Nem lehet  %s napnál későbbi lejáratot megadni",
    "%1$s shared »%2$s« with you" : "%1$s megosztotta veled »%2$s«",
    "%1$s shared »%2$s« with you." : "%1$s megosztotta veled »%2$s«.",
    "Click the button below to open it." : "Kattintson a lenti gombra a megnyitáshoz.",
    "The requested share does not exist anymore" : "A kért megosztás már nem létezik",
    "Could not find category \"%s\"" : "Ez a kategória nem található: \"%s\"",
    "Sunday" : "Vasárnap",
    "Monday" : "Hétfő",
    "Tuesday" : "Kedd",
    "Wednesday" : "Szerda",
    "Thursday" : "Csütörtök",
    "Friday" : "Péntek",
    "Saturday" : "Szombat",
    "Sun." : "Vas.",
    "Mon." : "Hé.",
    "Tue." : "Ke.",
    "Wed." : "Sze.",
    "Thu." : "Csü.",
    "Fri." : "Pén.",
    "Sat." : "Szo.",
    "Su" : "Va",
    "Mo" : "Hé",
    "Tu" : "Ke",
    "We" : "Sze",
    "Th" : "Cs",
    "Fr" : "Pé",
    "Sa" : "Szo",
    "January" : "Január",
    "February" : "Február",
    "March" : "Március",
    "April" : "Április",
    "May" : "Május",
    "June" : "Június",
    "July" : "Július",
    "August" : "Augusztus",
    "September" : "Szeptember",
    "October" : "Október",
    "November" : "November",
    "December" : "December",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Már.",
    "Apr." : "Ápr.",
    "May." : "Máj.",
    "Jun." : "Jún.",
    "Jul." : "Júl.",
    "Aug." : "Aug.",
    "Sep." : "Szep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Dec.",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "A felhasználónévben csak a következő karakterek engedélyezettek: \"a-z\", \"A-Z\", \"0-9\", és \"_.@-'\"",
    "A valid username must be provided" : "Érvényes felhasználónevet kell megadnia",
    "Username contains whitespace at the beginning or at the end" : "A felhasználónév szóközt tartalmaz az elején vagy a végén",
    "Username must not consist of dots only" : "A felhasználónév nem állhat csak pontokból",
    "A valid password must be provided" : "Érvényes jelszót kell megadnia",
    "The username is already being used" : "Ez a bejelentkezési név már foglalt",
    "Could not create user" : "Nem sikerült létrehozni a felhasználót",
    "User disabled" : "Felhasználó letiltva",
    "Login canceled by app" : "Bejelentkezés megszakítva az alkalmazás által",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "\"%1$s\" alkalmazást nem lehet telepíteni, mert a következő függőségek nem teljesülnek: %2$s",
    "a safe home for all your data" : "egy biztonságos hely az adataidnak",
    "File is currently busy, please try again later" : "A fájl jelenleg elfoglalt, kérjük próbáld újra később!",
    "Can't read file" : "Nem olvasható a fájl",
    "Application is not enabled" : "Az alkalmazás nincs engedélyezve",
    "Authentication error" : "Azonosítási hiba",
    "Token expired. Please reload page." : "A token lejárt. Frissítse az oldalt.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Nincs telepítve adatbázis-meghajtóprogram (sqlite, mysql vagy postgresql).",
    "Cannot write into \"config\" directory" : "Nem írható a \"config\" könyvtár",
    "Cannot write into \"apps\" directory" : "Nem írható az \"apps\" könyvtár",
    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file. See %s" : "Ez legtöbbször megoldható az app mappára a webszervernek adott írási joggal, vagy a config fájlban az alkalmazástár letiltásával. Lásd: %s",
    "Cannot create \"data\" directory" : "\"data\" mappa nem hozható létre",
    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Ez legtöbbször megoldható a gyökér mappára a webszervernek adott írási joggal. Lásd: %s",
    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Ez legtöbbször megoldható a gyökér mappára a webszervernek adott írási joggal. Lásd:  %s.",
    "Setting locale to %s failed" : "A lokalizáció %s-re való állítása nem sikerült",
    "Please install one of these locales on your system and restart your webserver." : "Kérjük állítsa be a következő lokalizációk valamelyikét a rendszeren és indítsa újra a webszervert!",
    "Please ask your server administrator to install the module." : "Kérje meg a rendszergazdát, hogy telepítse a modult!",
    "PHP module %s not installed." : "A %s PHP modul nincs telepítve.",
    "PHP setting \"%s\" is not set to \"%s\"." : "%s PHP beállítás nincs \"%s\"-re állítva.",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "A beállítás változtatása a php.ini fájlban újra futtatja a Nexcloud-ot",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload értéke: \"%s\" az elvárt \"0\" helyett",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "A probléma javításához állítsd a <code>mbstring.func_overload</code> értékét <code>0</code>-ra a php.ini fájlban.",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Legalább libxml2 2.7.0 szükséges. Jelenleg telepített: %s",
    "To fix this issue update your libxml2 version and restart your web server." : "A probléma javításához frissítsd a libxml2 verziót és indítsd újra a webszervert.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Úgy tűnik, hogy a PHP úgy van beállítva, hogy eltávolítja programok belsejében elhelyezett szövegblokkokat. Emiatt a rendszer több alapvető fontosságú eleme működésképtelen lesz.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Ezt valószínűleg egy gyorsítótár ill. kódgyorsító, mint pl, a Zend, OPcache vagy eAccelererator okozza.",
    "PHP modules have been installed, but they are still listed as missing?" : "A PHP modulok telepítve vannak, de a listában mégsincsenek felsorolva?",
    "Please ask your server administrator to restart the web server." : "Kérje meg a rendszergazdát, hogy indítsa újra a webszervert!",
    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 szükséges",
    "Please upgrade your database version" : "Kérem frissítse az adatbázis-szoftvert!",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Kérjük módosítsa a könyvtár elérhetőségi engedélybeállítását 0770-re, hogy a tartalmát más felhasználó ne listázhassa!",
    "Your data directory is readable by other users" : "Az adatkönyvtárad mások által olvasható",
    "Your data directory must be an absolute path" : "Az adatkönyvtára abszolút útvonal kell legyen",
    "Check the value of \"datadirectory\" in your configuration" : "Ellenőrizd a \"datadirectory\" értékét a konfigurációban",
    "Your data directory is invalid" : "Az adatkönyvtárad érvénytelen",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Győződj meg róla, hogy az adatmappa gyökerében legyen egy \".ocdata\" nevű fájl",
    "Action \"%s\" not supported or implemented." : "\"%s\" művelet nem támogatott vagy nem ismert.",
    "Authentication failed, wrong token or provider ID given" : "Azonosítás sikertelen, hibás token vagy szolgáltató lett megadva",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "A következő paraméterek hiányoznak, hogy végrehajtható legyen a kérés. Paraméterek: \"%s\"",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "ID \"%1$s\" már hasznalatban van a Felhő szolgáltatónál: \"%2$s\"",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "\"%s\" ID nem létezik a Felhő szolgáltatónal.",
    "Could not obtain lock type %d on \"%s\"." : "Nem sikerült %d típusú zárolást elérni itt: \"%s\".",
    "Storage unauthorized. %s" : "A tároló jogosulatlan. %s",
    "Storage incomplete configuration. %s" : "A tároló beállítása nem teljes. %s",
    "Storage connection error. %s" : "Tároló kapcsolódási hiba. %s",
    "Storage is temporarily not available" : "A tároló átmenetileg nem érthető el",
    "Storage connection timeout. %s" : "Tároló kapcsolat időtúllépés. %s",
    "Create" : "Létrehozás",
    "Change" : "Változtatás",
    "Delete" : "Törlés",
    "Share" : "Megosztás",
    "Unlimited" : "Korlátlan",
    "Verifying" : "Ellenőrzés",
    "Verifying …" : "Ellenőrzés...",
    "Verify" : "Ellenőrzés",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "%s megosztása sikertelen, mert a megosztási alrendszer nem engedi a %l típus megosztását",
    "Sharing %s failed, because the file does not exist" : "%s megosztása sikertelen, mert a fájl nem létezik",
    "Sharing %s failed, because you can not share with yourself" : "%s megosztása sikertelen, mert magaddal nem oszthatod meg",
    "Sharing %1$s failed, because the user %2$s does not exist" : "%1$s megosztása nem sikerült, mert %2$s felhasználó nem létezik",
    "Sharing %1$s failed, because the user %2$s is not a member of any groups that %3$s is a member of" : "%1$s megosztása nem sikerült, mert %2$s felhasználó nem tagja egyik olyan csoportnak sem, aminek %3$s tagja",
    "Sharing %1$s failed, because this item is already shared with %2$s" : "%1$s megosztása nem sikerült, mert ez már meg van osztva vele: %2$s",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "%1$s megosztása sikertelen, mert már meg van osztva %2$s felhasználóval",
    "Sharing %1$s failed, because the group %2$s does not exist" : "%1$s megosztása nem sikerült, mert %2$s csoport nem létezik",
    "Sharing %1$s failed, because %2$s is not a member of the group %3$s" : "%1$s megosztása nem sikerült, mert %2$s felhasználó nem tagja a %3$s csoportnak",
    "You need to provide a password to create a public link, only protected links are allowed" : "Meg kell adnia egy jelszót is, mert a nyilvános hivatkozások csak jelszóval védetten használhatók",
    "Sharing %s failed, because sharing with links is not allowed" : "%s megosztása nem sikerült, mert a hivatkozással történő megosztás nincs engedélyezve",
    "Not allowed to create a federated share with the same user" : "Azonos felhasználóval nem lehet létrehozni egyesített megosztást.",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable." : "%1$s megosztása sikertelen, mert %2$s nem található; talán a szerver jelenleg nem elérhető.",
    "Share type %1$s is not valid for %2$s" : "A %1$s megosztási típus nem érvényes %2$s-re",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Nem lehet beállítani a lejárati időt. A megosztások legfeljebb ennyi idővel járhatnak le a létrehozásukat követően: %s",
    "Cannot set expiration date. Expiration date is in the past" : "Nem lehet beállítani a lejárati időt, mivel a megadott lejárati időpont már elmúlt.",
    "Sharing failed, because the user %s is the original sharer" : "Megosztás sikertelen, mert %s felhasználó az eredeti megosztó",
    "Sharing %1$s failed, because the permissions exceed permissions granted to %2$s" : "%1$s megosztása nem sikerült, mert a jogosultságok túllépik azt, ami %2$s rendelkezésére áll",
    "Sharing %s failed, because resharing is not allowed" : "%s megosztása nem sikerült, mert a megosztás továbbadása nincs engedélyezve",
    "Sharing %1$s failed, because the sharing backend for %2$s could not find its source" : "%1$s megosztása nem sikerült, mert %2$s megosztási alrendszere nem találja",
    "Sharing %s failed, because the file could not be found in the file cache" : "%s megosztása nem sikerült, mert a fájl nem található a gyorsítótárban"
},
"nplurals=2; plural=(n != 1);");
